==> openshift-model-hive-6.7.2-sources.jar: io/fabric8/openshift/api/model/hive/v1/OpenStackClusterDeprovisionBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class OpenStackClusterDeprovisionBuilder extends OpenStackClusterDeprovisionFluentImpl<OpenStackClusterDeprovisionBuilder> implements VisitableBuilder<OpenStackClusterDeprovision,OpenStackClusterDeprovisionBuilder>{
  public OpenStackClusterDeprovisionBuilder() {
    this(false);
  }
  public OpenStackClusterDeprovisionBuilder(Boolean validationEnabled) {
    this(new OpenStackClusterDeprovision(), validationEnabled);
  }
  public OpenStackClusterDeprovisionBuilder(OpenStackClusterDeprovisionFluent<?> fluent) {
    this(fluent, false);
  }
  public OpenStackClusterDeprovisionBuilder(OpenStackClusterDeprovisionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new OpenStackClusterDeprovision(), validationEnabled);
  }
  public OpenStackClusterDeprovisionBuilder(OpenStackClusterDeprovisionFluent<?> fluent,OpenStackClusterDeprovision instance) {
    this(fluent, instance, false);
  }
  public OpenStackClusterDeprovisionBuilder(OpenStackClusterDeprovisionFluent<?> fluent,OpenStackClusterDeprovision instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withCertificatesSecretRef(instance.getCertificatesSecretRef());
      fluent.withCloud(instance.getCloud());
      fluent.withCredentialsSecretRef(instance.getCredentialsSecretRef());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public OpenStackClusterDeprovisionBuilder(OpenStackClusterDeprovision instance) {
    this(instance,false);
  }
  public OpenStackClusterDeprovisionBuilder(OpenStackClusterDeprovision instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withCertificatesSecretRef(instance.getCertificatesSecretRef());
      this.withCloud(instance.getCloud());
      this.withCredentialsSecretRef(instance.getCredentialsSecretRef());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  OpenStackClusterDeprovisionFluent<?> fluent;
  Boolean validationEnabled;
  public OpenStackClusterDeprovision build() {
    OpenStackClusterDeprovision buildable = new OpenStackClusterDeprovision(fluent.getCertificatesSecretRef(),fluent.getCloud(),fluent.getCredentialsSecretRef());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-hive-6.8.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/OpenStackClusterDeprovisionBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class OpenStackClusterDeprovisionBuilder extends OpenStackClusterDeprovisionFluent<OpenStackClusterDeprovisionBuilder> implements VisitableBuilder<OpenStackClusterDeprovision,OpenStackClusterDeprovisionBuilder>{
  public OpenStackClusterDeprovisionBuilder() {
    this(false);
  }
  public OpenStackClusterDeprovisionBuilder(Boolean validationEnabled) {
    this(new OpenStackClusterDeprovision(), validationEnabled);
  }
  public OpenStackClusterDeprovisionBuilder(OpenStackClusterDeprovisionFluent<?> fluent) {
    this(fluent, false);
  }
  public OpenStackClusterDeprovisionBuilder(OpenStackClusterDeprovisionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new OpenStackClusterDeprovision(), validationEnabled);
  }
  public OpenStackClusterDeprovisionBuilder(OpenStackClusterDeprovisionFluent<?> fluent,OpenStackClusterDeprovision instance) {
    this(fluent, instance, false);
  }
  public OpenStackClusterDeprovisionBuilder(OpenStackClusterDeprovisionFluent<?> fluent,OpenStackClusterDeprovision instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new OpenStackClusterDeprovision());

    if (instance != null) {
      fluent.withCertificatesSecretRef(instance.getCertificatesSecretRef());
      fluent.withCloud(instance.getCloud());
      fluent.withCredentialsSecretRef(instance.getCredentialsSecretRef());
      fluent.withCertificatesSecretRef(instance.getCertificatesSecretRef());
      fluent.withCloud(instance.getCloud());
      fluent.withCredentialsSecretRef(instance.getCredentialsSecretRef());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public OpenStackClusterDeprovisionBuilder(OpenStackClusterDeprovision instance) {
    this(instance,false);
  }
  public OpenStackClusterDeprovisionBuilder(OpenStackClusterDeprovision instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new OpenStackClusterDeprovision());

    if (instance != null) {
      this.withCertificatesSecretRef(instance.getCertificatesSecretRef());
      this.withCloud(instance.getCloud());
      this.withCredentialsSecretRef(instance.getCredentialsSecretRef());
      this.withCertificatesSecretRef(instance.getCertificatesSecretRef());
      this.withCloud(instance.getCloud());
      this.withCredentialsSecretRef(instance.getCredentialsSecretRef());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  OpenStackClusterDeprovisionFluent<?> fluent;
  Boolean validationEnabled;
  public OpenStackClusterDeprovision build() {
    OpenStackClusterDeprovision buildable = new OpenStackClusterDeprovision(fluent.buildCertificatesSecretRef(),fluent.getCloud(),fluent.buildCredentialsSecretRef());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
